-- if animated_graphics is true then
-- "basic-pressure-plate" is invisible, type = "constant-combinator"
-- "decorative-basic-plate-inactive" is visble, type = "decorative", render_layer = "floor"
-- "decorative-basic-plate-active" is visble, type = "decorative", render_layer = "floor"

-- if animated_graphics is false then
-- "basic-pressure-plate" is visible, type = "constant-combinator"
-- "decorative-basic-plate-inactive" is invisble, type = "decorative", render_layer = "floor"
-- "decorative-basic-plate-active" is invisble, type = "decorative", render_layer = "floor"

require "defines"

--create global variables
script.on_init(function()
	if global.basic_pp_list == nil then
		global.basic_pp_list = {}
	end
end)

script.on_load(function()
	if global.basic_pp_list == nil then
		global.basic_pp_list = {}
	end
end)

--script events
script.on_event(defines.events.on_built_entity, function(event)
	if (event.created_entity.name == "basic-pressure-plate") then
		create_basic_pp(event.created_entity)
	end
end)

script.on_event(defines.events.on_robot_built_entity, function(event)
	if (event.created_entity.name == "basic-pressure-plate") then
		create_basic_pp(event.created_entity)
	end
end)

script.on_event(defines.events.on_preplayer_mined_item, function(event)
	if (event.entity.name == "basic-pressure-plate") then
		remove_basic_pp(event.entity)
	end
end)

script.on_event(defines.events.on_robot_pre_mined, function(event)
	if (event.entity.name == "basic-pressure-plate") then
		remove_basic_pp(event.entity)
	end
end)

script.on_event(defines.events.on_entity_died, function(event)
	if (event.entity.name == "basic-pressure-plate") then
		remove_basic_pp(event.entity)
	end
end)

script.on_event(defines.events.on_tick, function(event)
	for pp_xykey, pp_state in pairs(global.basic_pp_list) do
		set_basic_pp(pp_xykey, pp_state)
	end
end)

--functions
function create_basic_pp(entity)
	entity.operable = false
	local pp_mask = entity.surface.create_entity{name = "decorative-basic-plate-inactive", position = {entity.position.x, entity.position.y}, force = game.forces.neutral}
	pp_mask.destructible = false
	global.basic_pp_list[entity.position.x .. "," .. entity.position.y .. "," .. entity.surface.name] = {basic_pp_entity = entity, mask = pp_mask, active = false}
end

function remove_basic_pp(entity)
	local key_string = entity.position.x .. "," .. entity.position.y .. "," .. entity.surface.name
	if entity.surface.find_entity("decorative-basic-plate-inactive", entity.position) or entity.surface.find_entity("decorative-basic-plate-active", entity.position) then
		global.basic_pp_list[key_string].mask.destroy()
	end
	global.basic_pp_list[key_string] = nil
end

function set_basic_pp(key, value)
	if game.player.position.x >= (value.basic_pp_entity.position.x - 0.5) and game.player.position.x < (value.basic_pp_entity.position.x + 0.5) and game.player.position.y >= (value.basic_pp_entity.position.y - 0.5) and game.player.position.y < (value.basic_pp_entity.position.y + 0.5) then
		if value.active == false then
			global.basic_pp_list[key].active = true
			value.basic_pp_entity.set_circuit_condition(1, {parameters = {{count = 1, index = 1, signal = {name = "signal-pressure-player", type = "virtual"}}}})
			
			if value.basic_pp_entity.surface.find_entity("decorative-basic-plate-inactive", value.basic_pp_entity.position) then
				global.basic_pp_list[key].mask.destroy()
			end
			global.basic_pp_list[key].mask = value.basic_pp_entity.surface.create_entity{name = "decorative-basic-plate-active", position = {value.basic_pp_entity.position.x, value.basic_pp_entity.position.y}, force = game.forces.neutral}
			global.basic_pp_list[key].mask.destructible = false
		end
	else
		if value.active == true then
			global.basic_pp_list[key].active = false
			value.basic_pp_entity.set_circuit_condition(1, {parameters = {{count = 0, index = 1, signal = {name = "signal-pressure-player", type = "virtual"}}}})
			
			if value.basic_pp_entity.surface.find_entity("decorative-basic-plate-active", value.basic_pp_entity.position) then
				global.basic_pp_list[key].mask.destroy()
			end
			global.basic_pp_list[key].mask = value.basic_pp_entity.surface.create_entity{name = "decorative-basic-plate-inactive", position = {value.basic_pp_entity.position.x, value.basic_pp_entity.position.y}, force = game.forces.neutral}
			global.basic_pp_list[key].mask.destructible = false
		end
	end
end